################################################################
# pp.client-plone
# (C) 2013-2019,  ZOPYX, D-72074 Tuebingen, www.zopyx.com
################################################################

"""'
ZCML directives for pp.client-plone
"""

import os

from zope.interface import Interface
from zope.schema import TextLine

from pp.core.resources_registry import registerResource

class IResourcesDirectory(Interface):
    """ Used for specifying SmartPrintNG resources """

    name = TextLine(
        title=u"name",
        description=u'Resource name',
        default=u"",
        required=True)

    directory = TextLine(
        title=u"Directory name",
        description=u'Directory path containing template, styles and other resources',
        default=u"",
        required=True)


def resourcesDirectory(_context, name, directory):
    zcml_filename = _context.info.file
    directory = os.path.join(os.path.dirname(zcml_filename), directory)
    registerResource(name, directory)




################################################################
# pp.client-plone
# (C) 2013-2019,  ZOPYX, D-72074 Tuebingen, www.zopyx.com
################################################################

from zope import schema
from zope.interface import Interface
from pp.client.plone.i18n import MessageFactory as _


class IPPServer(Interface):
    """ Marker interface for Produce & Publish server """


class IPloneClientConnectorLayer(Interface):
    """A brower layer specific to my product """


class IPPClientPloneSettings(Interface):
    """ pp.client-plone settings """

    server_url = schema.TextLine(
        title=_(u'URL of Produce & Publish webservice'),
        description=_(u'URL of Produce & Publish webservice'),
        default=u'https://pp-server.zopyx.com'
    )

    server_username = schema.TextLine(
        title=_(u'Username for webservice'),
        description=_(u'Username for webservice'),
        required=False,
        default=u''
    )

    server_password = schema.TextLine(
        title=_(u'Password for webservice'),
        description=_(u'Password for webservice'),
        required=False,
        default=u''
    )




# -*- coding: utf-8 -*-

################################################################
# pp.client-plone
# (C) 2013-2019,  ZOPYX, D-72074 Tuebingen, www.zopyx.com
################################################################


import os

import pkg_resources

from zope.component import getUtility
from Products.Five.browser import BrowserView

from pp.client.plone.interfaces import IPPServer


class Demo(BrowserView):
    """ P&P server demo """

    def demo(self):
        service = getUtility(IPPServer)
        base_dir = pkg_resources.get_distribution('pp.client-python').location
        data_dir = os.path.join(base_dir, 'pp', 'client', 'python', 'test_data', 'html')
        output_filename = service(data_dir, 'princexml')
        with open(output_filename, 'rb') as fp:
            self.request.response.setHeader('content-type', 'application/pdf')
            self.request.response.setHeader('content-length', str(os.path.getsize(output_filename)))
            self.request.response.write(fp.read())



# -*- coding: utf-8 -*-

################################################################
# pp.client-plone
# (C) 2013-2019,  ZOPYX, D-72074 Tuebingen, www.zopyx.com
################################################################

import furl

from zope.component import getUtility
from plone.registry.interfaces import IRegistry

from pp.client.python import pdf
from pp.client.plone.interfaces import IPPClientPloneSettings
from pp.client.plone.logger import LOG


def convert(work_directory, converter):
    """ Convert content from given `work_directory` using `converter`
        through Produce & Publish server.
    """

    registry = getUtility(IRegistry)
    settings = registry.forInterface(IPPClientPloneSettings)

    r = furl.furl(settings.server_url)
    if settings.server_username:
        r.username = settings.server_username
    if settings.server_password:
        r.password = settings.server_password
    server_url = str(r)

    result = pdf.pdf(work_directory, converter, server_url=server_url)
    if result['status']  == 'OK':
        output_filename = result['output_filename']
        LOG.info('Output file: %s' % output_filename)
        return output_filename
    else:
        LOG.error('Conversion failed ({})'.format(result['output']))
        raise RuntimeError(result['output'])




# -*- coding: utf-8 -*-

################################################################
# pp.client-plone
# (C) 2013,  ZOPYX Limited, D-72074 Tuebingen, Germany
################################################################


import furl
from Products.Five.browser import BrowserView
from plone.app.registry.browser import controlpanel
from plone.registry.interfaces import IRegistry
from zope.component import getUtility
from pp.client.plone.interfaces import IPPClientPloneSettings
from pp.client.plone.i18n import MessageFactory as _


class PPClientPloneSettingsEditForm(controlpanel.RegistryEditForm):

    schema = IPPClientPloneSettings
    label = _(u'Produce & Publish PDF')
    description = _(u'')

    def updateFields(self):
        super(PPClientPloneSettingsEditForm, self).updateFields()

    def updateWidgets(self):
        super(PPClientPloneSettingsEditForm, self).updateWidgets()


class PPClientPloneSettingsControlPanel(controlpanel.ControlPanelFormWrapper):
    form = PPClientPloneSettingsEditForm


class ConnectionTest(BrowserView):

    def connection_test(self):

        registry = getUtility(IRegistry)
        settings = registry.forInterface(IPPClientPloneSettings)

        r = furl.furl(settings.server_url)
        if settings.server_username:
            r.username = settings.server_username
        if settings.server_password:
            r.password = settings.server_password
        server_url = str(r)

        from pp.client.python import version
        result = version.version(server_url=server_url)
        if result.status_code == 200:
            self.context.plone_utils.addPortalMessage(u'Connection to Produce & Publish Server is OK')
        else:
            msg = u'Connection to Produce & Publish Server is not functional (HTTP Code {}, {})'.format(result.status_code, result.text)
            self.context.plone_utils.addPortalMessage(msg, 'error')
        return self.request.response.redirect(self.context.absolute_url() + '/@@pp-client-plone-settings')




from setuptools import setup, find_packages
import os

version = '1.0.0'

setup(name='pp.connector.plone',
      version=version,
      description="Produce & Publisher Plone Client Connector",
      long_description=open(os.path.join("docs", "source", "README.rst")).read() + "\n" +
                       open(os.path.join("docs", "source", "HISTORY.rst")).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Framework :: Plone",
        "Framework :: Plone :: 5.1",
        "Framework :: Plone :: 5.2",
        "Framework :: Zope2",
        "Framework :: Zope :: 2",
        "Framework :: Zope :: 4",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='PDF Plone Python EBook EPUB',
      author='Andreas Jung',
      author_email='info@zopyx.com',
      url='http://pypi.python.org/pypi/pp.client.plone',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['pp', 'pp.client'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'plone.browserlayer',
          'pp.client-python',
          'pp.core',
          'furl',
          # -*- Extra requirements: -*-
      ],
      tests_require=['zope.testing'],
      entry_points="""
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )

